Changelog
=========

* :feature:`-` Use UV in CI
* :feature:`-` Support for Python version >= 3.8, <= 3.13
* :feature:`-` Support for Python version 3.12
* :feature:`-` Use ``pyproject.toml`` for package configuration
* :feature:`-` Support for Python versions 3.9, 3.10, 3.11
* :feature:`-` Move CI to GitHub actions (from Travis CI)
* :feature:`-` Support for Python version 3.8
* :feature:`43` Drop support for Python version < 3.5
* :feature:`41` Add Sphinx extension
* :release:`2.4.0 <03-09-2019>`
* :feature:`39` Add ``guard`` argument to ``register``
* :release:`2.3.1 <28-08-2018>`
* :bug:`36` Ensure ``define_hook`` handles hook kwargs even if it already being defined
* :bug:`30` Switch to PBR
* :release:`2.3.0 <07-01-2018>`
* :feature:`17` Add ``registered`` context
* :release:`2.2.0 <22-04-2017>`
* :feature:`-` Support mechanism for forbid hooks muting
* :bug:`25` ``unregister_token`` iter all hooks (recursively) including empty registrations
* :release:`2.1.0 <01-01-2017>`
* :feature:`24` Add optional type checking to hook arguments
* :feature:`21` Support registration priorities for controlling calling order
* :feature:`-` Use vintage for hook deprecations
* :release:`2.0.0 <18-05-2016>`
* :feature:`17` Support toggle registrations
* :feature:`16` Support non-reentrant hooks
* :feature:`-` Completely move to Logbook for logging
* :release:`1.1.0 <10-01-2016>`
* :feature:`-` Support deprecated hooks
* :release:`1.0.0 <29-07-2015>`
* :feature:`11` Add needs/provides mechanism for fine grained control of dependencies
* :feature:`10` Add support for pre-trigger callbacks
* :feature:`9` Add support for registration blueprints
* :release:`0.10.0 <09-02-2015>`
* :feature:`6` Add option to disable group strictness
* :release:`0.9.1 <15-01-2015>`
* :bug:`-` Registration objects had no proper ``__repr__`` implementation
* :release:`0.9.0 <19-10-2014>`
* :feature:`4` Added support for muting hooks
* :release:`0.8.0 <5-8-2014>`
* :feature:`2` Added tags support
* :feature:`-` Testing improvements
* :release:`0.7.0 <11-6-2014>`
* :feature:`-` Add 'hook' argument for on_handler_exception
* :release:`0.6.0 <17-5-2014>`
* :feature:`-` Many fixes and cosmetics
* :release:`0.5.0 <14-5-2014>`
* :feature:`-` Support built-in docs for hooks
* :feature:`-` Support undefine_all for subgroups of the global group
* :feature:`-` Support token unregistrations
* :release:`0.4.0 <12-5-2014>`
* :feature:`-` Support strict groups and registration
* :release:`0.3.0 <10-5-2014>`
* :feature:`-` Support hook dependencies
* :release:`0.2.0 <9-5-2014>`
* :feature:`-` Stabilize docs and basic functionality
* :release:`0.1.0 <2-5-2014>`


